@@ -65,6 +65,69 @@
 			},
 
 			// Expand term node
+			_displayTermSubnodes: function(term, nodes) {
+				var source = $("A:econtains(" + term.replace('&#039;','\'') + ")").siblings('IMG.plminus');
+				var source_div = $(source).closest('DIV').get(0);
+				var tree = $(source).closest('DIV.tree');
+				var show_links = tree.data('ztfy-tree-details') != 'off';
+				var $target = $('DIV.subnodes', $(source).closest('DIV').get(0));
+				$target.empty();
+				for (var index in nodes) {
+					var node = nodes[index];
+					var $div = $('<div></div>');
+					$('<img />').addClass('plminus')
+								.attr('src', node.expand ? '/--static--/ztfy.thesaurus/img/plus.png'
+														 : '/--static--/ztfy.thesaurus/img/lline.png')
+								.click(function() {
+									$.ZTFY.thesaurus.tree.expand(this);
+								})
+								.appendTo($div);
+					$('<a></a>').addClass(show_links ? 'label' : '')
+								.addClass(node.cssClass)
+								.click(function() {
+									$.ZTFY.thesaurus.tree.openTerm(this);
+								})
+								.html(node.label).appendTo($div);
+					$('<span> </span>').appendTo($div);
+					for (var ind_ext in node.extensions) {
+						var extension = node.extensions[ind_ext];
+						$('<img />').addClass('extension')
+									.attr('src', extension.icon)
+									.data('ztfy-view', extension.view)
+									.click(function() {
+										$.ZTFY.thesaurus.tree.openExtension(this);
+									})
+									.appendTo($div);
+					}
+					node.extracts.reverse();
+					for (var ind_ext in node.extracts) {
+						var extract = node.extracts[ind_ext];
+						var checker = $('DIV.extract SPAN.showhide[data-ztfy-extract-name="' + extract.name + '"]');
+						var $span = $('<span></span>').addClass('square')
+													  .addClass(extract.used ? 'used' : null)
+													  .attr('title', extract.title)
+													  .attr('data-ztfy-extract-name', extract.name);
+						if ($(checker).hasClass('hide')) {
+							$span.css('visibility', 'hidden');
+						} else if ($('SPAN[data-ztfy-extract-name="'+extract.name+'"]:first', source_div).hasClass('used')) {
+							$span.css('background-color', extract.used ? '#'+extract.color : 'white');
+							$span.click(function() {
+								$.ZTFY.thesaurus.tree.switchExtract(this);
+							});
+						} else {
+							$span.css('background-color', 'silver');
+						}
+						$span.appendTo($div);
+					}
+					$('<div></div>').addClass('subnodes').appendTo($div);
+					$div.appendTo($target);
+					if (node.subnodes) {
+						$.ZTFY.thesaurus.tree._displayTermSubnodes(node.label, node.subnodes);
+					}
+				}
+				$(source).attr('src', '/--static--/ztfy.thesaurus/img/minus.png');
+			},
+
 			expand: function(source) {
 				if ($(source).attr('src') == '/--static--/ztfy.thesaurus/img/plus.png') {
 					$(source).attr('src', '/--static--/ztfy.thesaurus/img/loader.gif');
@@ -81,63 +144,7 @@
 
 			_expandCallback: function(result, status) {
 				if (status == 'success') {
-					var term = result.term;
-					var source = $.data($.ZTFY.thesaurus.tree, 'source')[term];
-					var source_div = $(source).closest('DIV').get(0);
-					var tree = $(source).closest('DIV.tree');
-					var show_links = tree.data('ztfy-tree-details') != 'off';
-					var $target = $('DIV.subnodes', $(source).closest('DIV').get(0));
-					for (var index in result.nodes) {
-						var node = result.nodes[index];
-						var $div = $('<div></div>');
-						$('<img />').addClass('plminus')
-									.attr('src', node.expand ? '/--static--/ztfy.thesaurus/img/plus.png'
-															 : '/--static--/ztfy.thesaurus/img/lline.png')
-									.click(function() {
-										$.ZTFY.thesaurus.tree.expand(this);
-									})
-									.appendTo($div);
-						$('<a></a>').addClass(show_links ? 'label' : '')
-									.addClass(node.cssClass)
-									.click(function() {
-										$.ZTFY.thesaurus.tree.openTerm(this);
-									})
-									.html(node.label).appendTo($div);
-						$('<span> </span>').appendTo($div);
-						for (var ind_ext in node.extensions) {
-							var extension = node.extensions[ind_ext];
-							$('<img />').addClass('extension')
-										.attr('src', extension.icon)
-										.data('ztfy-view', extension.view)
-										.click(function() {
-											$.ZTFY.thesaurus.tree.openExtension(this);
-										})
-										.appendTo($div);
-						}
-						node.extracts.reverse();
-						for (var ind_ext in node.extracts) {
-							var extract = node.extracts[ind_ext];
-							var checker = $('DIV.extract SPAN.showhide[data-ztfy-extract-name="' + extract.name + '"]');
-							var $span = $('<span></span>').addClass('square')
-														  .addClass(extract.used ? 'used' : null)
-														  .attr('title', extract.title)
-														  .attr('data-ztfy-extract-name', extract.name);
-							if ($(checker).hasClass('hide')) {
-								$span.css('visibility', 'hidden');
-							} else if ($('SPAN[data-ztfy-extract-name="'+extract.name+'"]:first', source_div).hasClass('used')) {
-								$span.css('background-color', extract.used ? '#'+extract.color : 'white');
-								$span.click(function() {
-									$.ZTFY.thesaurus.tree.switchExtract(this);
-								});
-							} else {
-								$span.css('background-color', 'silver');
-							}
-							$span.appendTo($div);
-						}
-						$('<div></div>').addClass('subnodes').appendTo($div);
-						$div.appendTo($target);
-					}
-					$(source).attr('src', '/--static--/ztfy.thesaurus/img/minus.png');
+					$.ZTFY.thesaurus.tree._displayTermSubnodes(result.term, result.nodes);
 				}
 			},
 
@@ -174,6 +181,36 @@
 				}
 			},
 
+			// Find term in terms tree
+			findTerm: function(source) {
+				if (source instanceof $.Event) {
+					var source  = source.srcElement || source.target;
+				}
+				var term = $(source).siblings('INPUT').val();
+				if (term) {
+					if ($.browser.msie) {
+						term = $.UTF8.encode(term);
+					}
+					var context = $(source).parents('FIELDSET.search').siblings('DIV.tree').data('ztfy-base');
+					$.ZTFY.ajax.post(context + '/@@terms.html/@@ajax/getParentNodes', {'term': term}, $.ZTFY.thesaurus.tree._findCallback);
+				}
+			},
+
+			_findCallback: function(result, status) {
+				if (status == 'success') {
+					var status = result.status;
+					if (status == 'OK') {
+						$.ZTFY.thesaurus.tree._displayTermSubnodes(result.parent, result.nodes);
+						var element = $("A:econtains(" + result.term.replace('&#039;','\'') + ")", 'DIV.tree');
+						$('html,body').animate({scrollTop: element.offset().top-100}, 1000);
+						element.css('background-color', 'yellow')
+							   .on('mouseover', function() {
+								   $(this).animate({'background-color': $.Color('white')}, 2000);
+							   });
+					}
+				}
+			},
+
 			// Open term extension properties dialog
 			openExtension: function(source) {
 				var view = $(source).data('ztfy-view').replace('/ /g', '%20');
